<?php
/**
 * Archive Template
 *
 * Here we setup all logic and XHTML that is required for the category and tag archive page template.
 *
 * @package WooFramework
 * @subpackage Currents
 */
?>

<?php get_header(); ?>
    
<?php 	
/**
 * The Variables
 *
 * Setup default variables, overriding them if the "Theme Options" have been saved.
 */
	$settings = array(
					'thumb_w' => 100, 
					'thumb_h' => 100, 
					'thumb_align' => 'alignleft',
					'content_banner_ad_archive' => 'true',
					'ad_content' => 'true',
					'featured_category_archive' => 'true',
					'breadcrumbs_show' => 'false',
					'post_content' => 'excerpt',
					'excerpt_show' => 'false',
					'thumbnails_show' => 'false',
					'archive_featured' => 'true',
					'layout_width' => '800'
					);
					
	$settings = woo_get_dynamic_values( $settings );
?>
    <?php $paged = (get_query_var('paged')) ? get_query_var('paged') : 1; ?>
    
    <div id="content" class="col-full">
    
    	<?php if ( $settings['breadcrumbs_show'] == 'true' ) { ?>
			<section id="breadcrumbs">
				<?php woo_breadcrumbs(); ?>
			</section><!--/#breadcrumbs -->
		<?php } ?>  

		<?php if (have_posts()) : $count = 0; ?>
        
            <?php if (is_category()) { ?>
        	<header class="archive_header">
        		<span class="fl cat"><?php _e( 'Archive', 'woothemes' ); ?> | <?php echo single_cat_title(); ?></span> 
        		<span class="fr catrss"><?php $cat_id = get_cat_ID( single_cat_title( '', false ) ); echo '<a href="' . get_category_feed_link( $cat_id, '' ) . '">' . __( "RSS feed for this section", "woothemes" ) . '</a>'; ?></span>
        	</header>        
        
            <?php } elseif (is_day()) { ?>
            <header class="archive_header"><?php _e( 'Archive', 'woothemes' ); ?> | <?php the_time( get_option( 'date_format' ) ); ?></header>

            <?php } elseif (is_month()) { ?>
            <header class="archive_header"><?php _e( 'Archive', 'woothemes' ); ?> | <?php the_time( 'F, Y' ); ?></header>

            <?php } elseif (is_year()) { ?>
            <header class="archive_header"><?php _e( 'Archive', 'woothemes' ); ?> | <?php the_time( 'Y' ); ?></header>

            <?php } elseif (is_author()) { ?>
            <header class="archive_header"><?php _e( 'Archive by Author', 'woothemes' ); ?></header>

            <?php } elseif (is_tag()) { ?>
            <header class="archive_header"><?php _e( 'Tag Archives:', 'woothemes' ); ?> <?php echo single_tag_title( '', true ); ?></header>
            
            <?php } ?>

        <?php
        	// Display the description for this archive, if it's available.
        	woo_archive_description();
        ?>
        
        <div class="fix"></div>
        
        <?php if($paged != 1 OR $settings['archive_featured'] != "true") { ?>
        	<section id="main" class="col-left">
        <?php } ?>
            
        <?php while (have_posts()) : the_post(); $count++; ?>

        	<?php if(($count == 1 && $settings['archive_featured'] == "true" ) && $paged == 1) { ?>
                                                                    
            <!-- Post Starts -->
            <article <?php post_class('first-post'); ?>>
            
            	<?php
	    	    $image = '';
	    	    $has_embed = woo_embed( 'width='.$settings['layout_width'].'&height=365&key=embed&class=slide-video&id='.$post->ID );
	        	if ( $has_embed ) {
	        	    echo $has_embed;
	        	} else {
    				woo_image( '&width='.$settings['layout_width'].'&height=365&class=slide-image&link=src&noheight=true' );
	        	}
	        	?>
				
                <header <?php if ( $image == '' ) { ?>class="no-image" <?php } ?>>
                
                	<h1><a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h1>
                	
                	<?php woo_post_meta(); ?>
                	
                </header> 
                                     
            </article><!-- /.post -->
            
            <section id="main" class="col-left">
            
            <?php } else { ?>
            
             <!-- Post Starts -->
            <article <?php post_class(); ?>>
            
            	<?php if ( ( $settings['post_content'] != 'content' ) && ( $settings['thumbnails_show'] == 'true') ) { woo_image( 'width=' . $settings['thumb_w'] . '&height=' . $settings['thumb_h'] . '&class=thumbnail ' . $settings['thumb_align'] ); } ?>

                <header>
                
                	<h1><a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h1>
                	
                	<?php woo_post_meta(); ?>
                	
                </header>
                
				<?php if( $settings['excerpt_show'] == 'true' ) : ?>
                <section class="excerpt entry">
                	 
                	 <?php 
                	 if ( $settings['post_content'] == 'content' ) { 
                	 	the_content( __( 'Continue Reading &rarr;', 'woothemes' ) ); 
                	 } else { 
                	 	the_excerpt(); 
                	 } ?>
                
                </section>
                
                <footer class="post-more">      
                	<?php if ( $settings['post_content'] == 'excerpt' ) { ?>
                    <span class="more-link"><a href="<?php the_permalink(); ?>" title="<?php esc_attr_e( 'Continue Reading &rarr;', 'woothemes' ); ?>"><?php _e( 'Continue Reading &rarr;', 'woothemes' ); ?></a></span>
                    <?php } ?>
                </footer>   
                <?php endif; ?>
                                     
            </article><!-- /.post -->
            
            <?php } ?>
            
        <?php endwhile; else: ?>
        
            <article <?php post_class(); ?>>
                <p><?php _e( 'Sorry, no posts matched your criteria.', 'woothemes' ); ?></p>
            </article><!-- /.post -->
        
        <?php endif; ?>  
    
			<?php woo_pagenav(); ?>
                
		</section><!-- /#main -->

        <?php get_sidebar(); ?>

    </div><!-- /#content -->
    
    <?php if ( ( $settings['content_banner_ad_archive'] == 'true' ) || ( $settings['ad_content'] == 'true' ) ) { get_template_part ( 'includes/content-banner' ); } ?>
    
   	<?php if ( $settings['featured_category_archive'] == 'true' ) { get_template_part ( 'includes/featured-category' ); } ?> 
		
<?php get_footer(); ?>