<?php
if ( ! defined( 'ABSPATH' ) ) exit;
/*---------------------------------------------------------------------------------*/
/* Custom Subscribe Widget */
/*---------------------------------------------------------------------------------*/

class Woo_CustomSubscribeWidget extends WP_Widget {
	var $settings = array( 'content', 'buttontext', 'buttonurl' );

	function __construct() {
		$widget_ops = array( 'description' => 'Display the Custom Subscribe Widget.' );
		parent::__construct( false, __( 'Woo - Custom Subscription', 'woothemes' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args, EXTR_SKIP );
		$instance = $this->woo_enforce_defaults( $instance );
		extract( $instance, EXTR_SKIP );

		echo $before_widget; ?>

		<?php if ( $content != '' ) { ?>
			<p><?php echo $content; ?></p>
		<?php } ?>

    	<?php if ( $buttontext != '' || $buttonurl != '' ) { ?>
    		<span class="button-wrap fix">
    			<?php if ( $buttonurl != '' && $buttontext != '' ) { ?>
    				<a class="button" href="<?php echo $buttonurl; ?>" title="<?php echo $buttontext; ?>"><?php echo $buttontext; ?></a>
    			<?php }  else { ?>
    				<?php echo $buttontext; ?>
    			<?php } ?>
    		</span>
		<?php } ?>

<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$new_instance = $this->woo_enforce_defaults( $new_instance );
		return $new_instance;
	}

	function woo_enforce_defaults( $instance ) {
		$settings = array();
		$defaults = $this->woo_get_settings();
		$settings = wp_parse_args( $instance, $defaults );

		return $settings;
	}

	/**
	 * Provides an array of the settings with the setting name as the key and the default value as the value
	 * This cannot be called get_settings() or it will override WP_Widget::get_settings()
	 */
	function woo_get_settings() {
		// Set the default to a blank string
		$settings = array_fill_keys( $this->settings, '' );
		// Now set the more specific defaults
		$settings['content']  = 'Get the Full Experience';
		$settings['buttontext']  = 'Subscribe Today';
		$settings['buttonurl']  = site_url();
		return $settings;
	}

	function form( $instance ) {
		$instance = $this->woo_enforce_defaults( $instance );
		extract( $instance, EXTR_SKIP );
		?>
			<p>
				<label for="<?php echo $this->get_field_id('content'); ?>"><?php _e('Content:','woothemes'); ?></label>
				<input type="text" name="<?php echo $this->get_field_name('content'); ?>" value="<?php echo esc_attr( $content ); ?>" class="widefat" id="<?php echo $this->get_field_id('content'); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('buttontext'); ?>"><?php _e('Button Text:','woothemes'); ?></label>
				<input type="text" name="<?php echo $this->get_field_name('buttontext'); ?>" value="<?php echo esc_attr( $buttontext ); ?>" class="widefat" id="<?php echo $this->get_field_id('buttontext'); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('buttonurl'); ?>"><?php _e('Button URL:','woothemes'); ?></label>
				<input type="text" name="<?php echo $this->get_field_name('buttonurl'); ?>" value="<?php echo esc_attr( $buttonurl ); ?>" class="widefat" id="<?php echo $this->get_field_id('buttonurl'); ?>" />
			</p>
<?php
	}
}

register_widget( 'Woo_CustomSubscribeWidget' );

if ( is_active_widget( null, null, 'woo_embedwidget' ) == true ) {
	add_action( 'wp_footer','woo_widget_custom_subscribe_js' );
}

function woo_widget_custom_subscribe_js() {

}
