<?php
if ( ! defined( 'ABSPATH' ) ) exit;
/*---------------------------------------------------------------------------------*/
/* Embed Widget */
/*---------------------------------------------------------------------------------*/

class Woo_EmbedWidget extends WP_Widget {
	var $settings = array( 'title', 'cat_id', 'width', 'limit', 'tag', 'override' );

	function __construct() {
		$widget_ops = array( 'description' => 'Display the Embed code from posts in tab like fashion.' );
		parent::__construct( false, __( 'Woo - Embed/Video', 'woothemes' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args, EXTR_SKIP );
		$instance = $this->woo_enforce_defaults( $instance );
		extract( $instance, EXTR_SKIP );

		// Default Post Query Args
		$post_args = array('numberposts' => $limit, 'meta_key' => 'embed', 'meta_value' => '', 'meta_compare' => '!=');
		$single_post = false;
		$original_cat_id = $cat_id;
		$original_tag = $tag;
		if ( $override == 'on' ) {
			$override = true;
		} else {
			$override = false;
		}
		if ( is_single() && $override ) {
			// Single Page
			$single_post = true;
			global $post;
			$embed = woo_get_embed( 'embed', $width, '', 'widget_video', $post->ID );
		} elseif ( is_category() && $override ) {
			// Category Archive Page
			$cat_id = get_cat_ID( single_cat_title( '', false ) );
			$post_args['cat'] = $cat_id;
		} elseif ( is_tag() && $override ) {
			// Tag Archive Page
			$term = get_queried_object();
			$tag_id = $term->term_id;
			$post_args['tag_id'] = $tag_id;
		} else {
			// All Other Pages based on widget settings
			$post_args['cat'] = $original_cat_id;
			$post_args['tag'] = $original_tag;
		} // End If Statement

		// Posts Query
		$myposts = get_posts( $post_args );

		$post_list = '';
		$count = 0;
		$active = 'active';
		$display = '';

		echo $before_widget;
		echo $before_title . apply_filters('widget_title', $title, $instance, $this->id_base) . $after_title;
		if ( isset( $myposts ) && !$single_post && !$override ) {

			// Categories, Tags, Other
			foreach( $myposts as $mypost ) {
				$embed = woo_get_embed( 'embed', $width, '', 'widget_video', $mypost->ID );
				if ( $embed ) {
					$count++;
					if ( $count > 1 ) {
						$active = '';
						$display = "style='display:none'";
					} // End If Statement
					echo '<div class="widget-video-unit" ' . $display . ' >';
					echo '<h4>' . get_the_title( $mypost->ID )  . "</h4>\n";
					echo $embed;
					$post_list .= "<li class='$active'><a href='#'>" . get_the_title( $mypost->ID ) . "</a></li>\n";
					echo '</div>';
				} // End If Statement
			} // End For Loop
		} else {

			// Single Post
			if ( $embed ) {
				// exclude the post from the loop
				$post_args['exclude'] = $post->ID;
			}

			// Get the first category and search for videos in that category
			$category = get_the_category($post->ID);
			$cat_id = $category[0]->cat_ID;
			$post_args['cat'] = $cat_id;
			$myposts = get_posts( $post_args );

			// If there are no videos in the category, search everything else from widget settings
			if ( count($myposts) == 0 ) {
			    $post_args['cat'] = $original_cat_id;
			    $post_args['tag'] = $original_tag;
			    $myposts = get_posts( $post_args );
			} // End If Statement

			foreach( $myposts as $mypost ) {
			    $embed = woo_get_embed( 'embed', $width, '', 'widget_video', $mypost->ID );
			    if ( $embed ) {
			    	$count++;
			    	if ( $count > 1 ) {
			    		$active = '';
			    		$display = "style='display:none'";
			    	} // End If Statement
			    	echo '<div class="widget-video-unit" ' . $display . ' >';
			    	echo '<h4>' . get_the_title( $mypost->ID )  . "</h4>\n";
			    	echo $embed;
			    	$post_list .= "<li class='$active'><a href='#'>" . get_the_title( $mypost->ID ) . "</a></li>\n";
			    	echo '</div>';
			    } // End If Statement
			} // End For Loop

		} // End If Statement
?>
		<ul class="widget-video-list">
			<?php echo $post_list; ?>
		</ul>
<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$new_instance = $this->woo_enforce_defaults( $new_instance );
		return $new_instance;
	}

	function woo_enforce_defaults( $instance ) {
		$settings = array();
		$defaults = $this->woo_get_settings();
		$instance = wp_parse_args( $instance, $defaults );
		$settings['title'] = strip_tags( $instance['title'] );
		$settings['tag'] = strip_tags( $instance['tag'] );
		$settings['cat_id'] = absint( $instance['cat_id'] );
		if ( $instance['cat_id'] < 1 )
			$settings['cat_id'] = '';
		// Enforce defaults if any of these three are empty
		$settings['limit'] = 10;
		$settings['width'] = 240;
		foreach ( array( 'limit', 'width' ) as $setting ) {
			$instance[$setting] = absint( $instance[$setting] );
			if ( $instance[$setting] < 1 )
				$settings[$setting] = $defaults[$setting];
		}
		$settings['override'] = 'on';
			if ( 'on' != $instance['override'] )
					$settings['override'] = 'off';
		return $settings;
	}

	/**
	 * Provides an array of the settings with the setting name as the key and the default value as the value
	 * This cannot be called get_settings() or it will override WP_Widget::get_settings()
	 */
	function woo_get_settings() {
		// Set the default to a blank string
		$settings = array_fill_keys( $this->settings, '' );
		// Now set the more specific defaults
		$settings['title']  = '';
		$settings['tag']  = '';
		$settings['limit']  = 10;
		$settings['width']  = 240;
		return $settings;
	}

	function form( $instance ) {
		$instance = $this->woo_enforce_defaults( $instance );
		extract( $instance, EXTR_SKIP );
		?>
			<p>
				<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:','woothemes'); ?></label>
				<input type="text" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo esc_attr( $title ); ?>" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" />
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('cat_id'); ?>"><?php _e('Category:','woothemes'); ?></label>
				<?php $cats = get_categories(); ?>
				<select name="<?php echo $this->get_field_name('cat_id'); ?>" class="widefat" id="<?php echo $this->get_field_id('cat_id'); ?>">
				<option value="">Disabled</option>
			<?php
				foreach ($cats as $cat){
					?><option value="<?php echo absint( $cat->cat_ID ); ?>" <?php selected( $cat->cat_ID, $cat_id ); ?>><?php echo esc_html( $cat->cat_name . ' (' . $cat->category_count . ')' ); ?></option><?php
				}
?>
				</select>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('tag'); ?>">Or <?php _e('Tag:','woothemes'); ?></label>
				<input type="text" name="<?php echo $this->get_field_name('tag'); ?>" value="<?php echo esc_attr( $tag ); ?>" class="widefat" id="<?php echo $this->get_field_id('tag'); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Size:','woothemes'); ?></label>
				<input type="text" size="2" name="<?php echo $this->get_field_name('width'); ?>" value="<?php echo esc_attr( $width ); ?>" class="" id="<?php echo $this->get_field_id('width'); ?>" />
				W
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('limit'); ?>"><?php _e('Limit (optional):','woothemes'); ?></label>
				<input type="text" name="<?php echo $this->get_field_name('limit'); ?>" value="<?php echo esc_attr( $limit ); ?>" class="" id="<?php echo $this->get_field_id('limit'); ?>" />
			</p>
			<p>
        		<input id="<?php echo $this->get_field_id( 'override' ); ?>" name="<?php echo $this->get_field_name( 'override' ); ?>" type="checkbox" <?php checked( $instance['override'], 'on' ); ?>> <?php _e( "Show related videos in same category on single posts/archive", 'woothemes' ); ?></input>
	   		</p>

<?php
	}
}

register_widget( 'Woo_EmbedWidget' );

if ( is_active_widget( null, null, 'woo_embedwidget' ) == true ) {
	add_action( 'wp_footer','woo_widget_embed_js' );
}

function woo_widget_embed_js() {
?>
<!-- Woo Video Player Widget -->
<script type="text/javascript">
	jQuery(document).ready(function(){
		var list = jQuery('ul.widget-video-list');
		list.find('a').click(function(){
			var clickedTitle = jQuery(this).text();
			jQuery(this).parent().parent().find('li').removeClass('active');
			jQuery(this).parent().addClass('active');
			var videoHolders = jQuery(this).parent().parent().parent().children('.widget-video-unit');
			videoHolders.each(function(){
				if(clickedTitle == jQuery(this).children('h4').text()){
					videoHolders.hide();
					jQuery(this).show();
				}
			})
			return false;
		})
	})
</script>
<?php
}
