<?php
/**
 * Index Template
 *
 * Here we setup all logic and XHTML that is required for the index template, used as both the homepage
 * and as a fallback template, if a more appropriate template file doesn't exist for a specific context.
 *
 * @package WooFramework
 * @subpackage Currents
 */
	get_header();
	
/**
 * The Variables
 *
 * Setup default variables, overriding them if the "Theme Options" have been saved.
 */
	
	$settings = array(
					'thumb_w' => 100, 
					'thumb_h' => 100, 
					'thumb_align' => 'alignleft',
					'content_banner_ad_home' => 'true',
					'ad_content' => 'true',
					'recent_news' => 'true',
					'featured_tags' => '',
					'featured_category' => 'true',
					'slider_exclude' => 'true',
					'featured' => 'false',
					'post_content' => 'excerpt',
					'excerpt_show' => 'false',
					'thumbnails_show' => 'false'
					);
					
	$settings = woo_get_dynamic_values( $settings );
?>

    <div id="content" class="col-full">
    
    	<?php if ($settings['featured_tags'] == '' ) { if (get_option('woo_exclude')) update_option("woo_exclude", ""); } ?>
    	<?php if ( !$paged && $settings['featured'] == "true" ) get_template_part ( 'includes/featured' ); ?>
    	
		<section id="main" class="col-left">      

		<?php 	
			$exclude = '';
			if ( $settings['slider_exclude'] == "true" AND $settings['featured'] == 'true' AND $settings['featured_tags'] != '' ) 
				$exclude = get_option('woo_exclude'); 
			$paged = (get_query_var('paged')) ? get_query_var('paged') : 1; 
			$args = array( 'post__not_in' => $exclude, 'paged'=> $paged);
		?>
        <?php
        	query_posts($args);
        	if ( have_posts() ) { $count = 0;
        		while ( have_posts() ) { the_post(); $count++;
        ?>                                                            
            <article <?php post_class(); ?>>
            
            	<?php if ( ( $settings['post_content'] != 'content' ) && ( $settings['thumbnails_show'] == 'true') ) { woo_image( 'width=' . $settings['thumb_w'] . '&height=' . $settings['thumb_h'] . '&class=thumbnail ' . $settings['thumb_align'] ); } ?>

                <header>
                
                	<h1><a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h1>
                	
                	<?php woo_post_meta(); ?>
                	
                </header>
                
				<?php if( $settings['excerpt_show'] == 'true' ) : ?>
                <section class="excerpt entry">
                	 
                	 <?php 
                	 if ( $settings['post_content'] == 'content' ) { 
                	 	the_content( __( 'Continue Reading &rarr;', 'woothemes' ) ); 
                	 } else { 
                	 	the_excerpt(); 
                	 } ?>
                
                </section>
                
                <footer class="post-more">      
                	<?php if ( $settings['post_content'] == 'excerpt' ) { ?>
                    <span class="more-link"><a href="<?php the_permalink(); ?>" title="<?php esc_attr_e( 'Continue Reading &rarr;', 'woothemes' ); ?>"><?php _e( 'Continue Reading &rarr;', 'woothemes' ); ?></a></span>
                    <?php } ?>
                </footer>   
                <?php endif; ?>
                                     
            </article><!-- /.post -->
                                                
        <?php
        		} // End WHILE Loop
        	} else {
        ?>
        
            <article <?php post_class(); ?>>
                <p><?php _e( 'Sorry, no posts matched your criteria.', 'woothemes' ); ?></p>
            </article><!-- /.post -->
        
        <?php } ?>
		<?php woo_pagenav(); ?>
                
		</section><!-- /#main -->

        <?php get_sidebar(); ?>

    </div><!-- /#content -->
    
    <?php if ( ( $settings['content_banner_ad_home'] == 'true' ) || ( $settings['ad_content'] == 'true' ) ) { get_template_part ( 'includes/content-banner' ); } ?>
    
    <?php if ( $settings['recent_news'] == 'true' ) { get_template_part ( 'includes/recent-news' ); } ?>   
    
   	<?php if ( $settings['featured_category'] == 'true' ) { get_template_part ( 'includes/featured-category' ); } ?> 
		
<?php get_footer(); ?>