<?php
/**
 * Search Template
 *
 * The search template is used to display search results from the native WordPress search.
 *
 * If no search results are found, the user is assisted in refining their search query in
 * an attempt to produce an appropriate search results set for the user's search query.
 *
 * @package WooFramework
 * @subpackage Currents
 */

 get_header();
 $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
?>
<?php 	
/**
 * The Variables
 *
 * Setup default variables, overriding them if the "Theme Options" have been saved.
 */
	$settings = array(
					'thumb_w' => 100, 
					'thumb_h' => 100, 
					'thumb_align' => 'alignleft',
					'content_banner_ad_archive' => 'true',
					'ad_content' => 'true',
					'featured_category_archive' => 'true',
					'breadcrumbs_show' => 'false',
					'post_content' => 'excerpt',
					'excerpt_show' => 'false',
					'thumbnails_show' => 'false'
					);
					
	$settings = woo_get_dynamic_values( $settings );
?>
    
    <div id="content" class="col-full">
    
    	<?php if ( $settings['breadcrumbs_show'] == 'true' ) { ?>
			<section id="breadcrumbs">
				<?php woo_breadcrumbs(); ?>
			</section><!--/#breadcrumbs -->
		<?php } ?>  

		<?php if (have_posts()) : $count = 0; ?>
        
            <header class="archive_header"><?php echo __( 'Search results:', 'woothemes' ) . ' '; the_search_query(); ?></header>

        <?php
        	// Display the description for this archive, if it's available.
        	woo_archive_description();
        ?>
        
        <div class="fix"></div>
        
   		<section id="main" class="col-left">
            
        <?php while (have_posts()) : the_post(); $count++; ?>
            
             <!-- Post Starts -->
            <article <?php post_class(); ?>>
            
            	<?php if ( ( $settings['post_content'] != 'content' ) && ( $settings['thumbnails_show'] == 'true' ) ) { woo_image( 'width=' . $settings['thumb_w'] . '&height=' . $settings['thumb_h'] . '&class=thumbnail ' . $settings['thumb_align'] ); } ?>

                <header>
                
                	<h1><a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h1>
                	
                	<?php woo_post_meta(); ?>
                	
                </header>
                
                <section class="excerpt entry">
                	
                	 <?php the_excerpt(); ?>
                
                </section>
                                     
                <footer class="post-more">      
                    <span class="more-link"><a href="<?php the_permalink(); ?>" title="<?php esc_attr_e( 'Continue Reading &rarr;', 'woothemes' ); ?>"><?php _e( 'Continue Reading &rarr;', 'woothemes' ); ?></a></span>
                </footer>   

            </article><!-- /.post -->
                        
        <?php endwhile; else: ?>
        
            <article <?php post_class(); ?>>
                <p><?php _e( 'Sorry, no posts matched your criteria.', 'woothemes' ); ?></p>
            </article><!-- /.post -->
        
        <?php endif; ?>  
    
			<?php woo_pagenav(); ?>
                
		</section><!-- /#main -->

        <?php get_sidebar(); ?>

    </div><!-- /#content -->
    
    <?php if ( ( $settings['content_banner_ad_archive'] == 'true' ) || ( $settings['ad_content'] == 'true' ) ) { get_template_part ( 'includes/content-banner' ); } ?>
    
   	<?php if ( $settings['featured_category_archive'] == 'true' ) { get_template_part ( 'includes/featured-category' ); } ?> 
		
<?php get_footer(); ?>